@@ -31,17 +31,17 @@ class AbstractStructureFilter(MSONable):
 
     @abc.abstractmethod
     def test(self, structure):
-        '''
+        """
         Returns a boolean for any structure. Structures that return true are
         kept in the Transmuter object during filtering.
-        '''
+        """
         return
 
     @staticmethod
     def from_dict(d):
         for trans_modules in ['filters']:
             mod = __import__('pymatgen.alchemy.' + trans_modules,
-                globals(), locals(), [d['@class']], -1)
+                             globals(), locals(), [d['@class']], -1)
             if hasattr(mod, d['@class']):
                 trans = getattr(mod, d['@class'])
                 return trans(**d['init_args'])
@@ -81,7 +81,7 @@ class ContainsSpecieFilter(AbstractStructureFilter):
             atomic_number = lambda x: x.Z
             filter_set = set(map(atomic_number, self._species))
             structure_set = set(map(atomic_number,
-                structure.composition.elements))
+                                structure.composition.elements))
         else:
             #compare by specie or element object
             filter_set = set(self._species)
@@ -98,23 +98,20 @@ class ContainsSpecieFilter(AbstractStructureFilter):
             return self._exclude
 
     def __repr__(self):
-        output = ["ContainsSpecieFilter with parameters:"]
-        output.append("species = {}".format(self._species))
-        output.append("strict_compare = {}".format(self._strict))
-        output.append("AND = {}".format(self._AND))
-        output.append("exclude = {}".format(self._exclude))
-        return  "\n".join(output)
+        return "\n".join(["ContainsSpecieFilter with parameters:",
+                          "species = {}".format(self._species),
+                          "strict_compare = {}".format(self._strict),
+                          "AND = {}".format(self._AND),
+                          "exclude = {}".format(self._exclude)])
 
     @property
     def to_dict(self):
-        d = {"version": __version__}
-        d["@module"] = self.__class__.__module__
-        d["@class"] = self.__class__.__name__
-        d["init_args"] = {"species": [str(sp) for sp in self._species],
-                          "strict_compare": self._strict,
-                          "AND": self._AND,
-                          "exclude": self._exclude}
-        return d
+        return {"version": __version__, "@module": self.__class__.__module__,
+                "@class": self.__class__.__name__,
+                "init_args": {"species": [str(sp) for sp in self._species],
+                              "strict_compare": self._strict,
+                              "AND": self._AND,
+                              "exclude": self._exclude}}
 
 
 class SpecieProximityFilter(AbstractStructureFilter):
@@ -156,13 +153,11 @@ class SpecieProximityFilter(AbstractStructureFilter):
 
     @property
     def to_dict(self):
-        d = {"version": __version__}
-        d["@module"] = self.__class__.__module__
-        d["@class"] = self.__class__.__name__
-        d["init_args"] = {"specie_and_min_dist_dict":
+        return {"version": __version__, "@module": self.__class__.__module__,
+                "@class": self.__class__.__name__,
+                "init_args": {"specie_and_min_dist_dict":
                               {str(sp): v
-                               for sp, v in self.specie_and_min_dist.items()}}
-        return d
+                              for sp, v in self.specie_and_min_dist.items()}}}
 
 
 class RemoveDuplicatesFilter(AbstractStructureFilter):
@@ -190,7 +185,7 @@ class RemoveDuplicatesFilter(AbstractStructureFilter):
 
         for s in self._structure_list:
             if self._sm._comparator.get_structure_hash(structure) ==\
-               self._sm._comparator.get_structure_hash(s):
+                    self._sm._comparator.get_structure_hash(s):
                 if self._sm.fit(s, structure):
                     return False
 
@@ -199,9 +194,6 @@ class RemoveDuplicatesFilter(AbstractStructureFilter):
 
     @property
     def to_dict(self):
-        d = {"version": __version__}
-        d["@module"] = self.__class__.__module__
-        d["@class"] = self.__class__.__name__
-        d["init_args"] = {"structure_matcher": self._sm.to_dict}
-
-        return d
\ No newline at end of file
+        return {"version": __version__, "@module": self.__class__.__module__,
+                "@class": self.__class__.__name__,
+                "init_args": {"structure_matcher": self._sm.to_dict}}
