@@ -21,23 +21,23 @@ class LinearAssignment(object):
     This class finds the solution to the Linear Assignment Problem.
     It finds a minimum cost matching between two sets, given a cost
     matrix.
-    
+
     This class is an implementation of the LAPJV algorithm described in:
-    R. Jonker, A. Volgenant. A Shortest Augmenting Path Algorithm for 
+    R. Jonker, A. Volgenant. A Shortest Augmenting Path Algorithm for
     Dense and Sparse Linear Assignment Problems. Computing 38, 325-340
     (1987)
-    
+
     .. attribute: min_cost:
-    
+
         The minimum cost of the matching
-        
+
     .. attribute: solution:
-    
+
         The matching of the rows to columns. i.e solution = [1, 2, 0]
-        would match row 0 to column 1, row 1 to column 2 and row 2 
+        would match row 0 to column 1, row 1 to column 2 and row 2
         to column 0. Total cost would be c[0, 1] + c[1, 2] + c[2, 0]
     """
-    
+
     def __init__(self, costs):
         """
         Args:
@@ -47,10 +47,10 @@ class LinearAssignment(object):
         """
         self.c = np.array(costs)
         self.n = len(costs)
-        
+
         #initialize solution vectors
-        self._x = np.zeros(self.n, dtype = np.int)-1
-        self._y = np.zeros(self.n, dtype = np.int)-1
+        self._x = np.zeros(self.n, dtype=np.int) - 1
+        self._y = np.zeros(self.n, dtype=np.int) - 1
 
         #if column reduction doesn't find a solution, augment with shortest
         #paths until one is found
@@ -64,7 +64,6 @@ class LinearAssignment(object):
         self.solution = self._x
         self._min_cost = None
 
-
     @property
     def min_cost(self):
         """
@@ -76,16 +75,15 @@ class LinearAssignment(object):
         self._min_cost = np.sum(self.c[np.arange(len(self.c)), self.solution])
         return self._min_cost
 
-
     def _column_reduction(self):
         """
         Column reduction and reduction transfer steps from LAPJV algorithm
         """
         #assign each column to its lowest cost row, ensuring that only row
         #or column is assigned once
-        i1, j = np.unique(np.argmin(self.c, axis = 0), return_index = True)
+        i1, j = np.unique(np.argmin(self.c, axis=0), return_index=True)
         self._x[i1] = j
-        
+
         #if problem is solved, return
         if len(i1) == self.n:
             return False
@@ -94,14 +92,13 @@ class LinearAssignment(object):
 
         #reduction_transfer
         #tempc is array with previously assigned matchings masked
-        self._v = np.min(self.c, axis = 0)
+        self._v = np.min(self.c, axis=0)
         tempc = self.c.copy()
         tempc[i1, j] = np.max(tempc.flatten()) * 10
-        mu = np.min(tempc[i1, :] - self._v[None, :], axis = 1)
+        mu = np.min(tempc[i1, :] - self._v[None, :], axis=1)
         self._v[j] -= mu
         return True
 
-
     def _augmenting_row_reduction(self):
         """
         Augmenting row reduction step from LAPJV algorithm
@@ -118,7 +115,7 @@ class LinearAssignment(object):
                 u2 = temp[j2]
 
                 if u1 < u2:
-                    self._v[j1] -= u2-u1
+                    self._v[j1] -= u2 - u1
                 elif self._y[j1] != -1:
                     j1 = j2
                 k = self._y[j1]
@@ -130,7 +127,6 @@ class LinearAssignment(object):
                 if np.allclose(u1, u2) or k == -1:
                     break
 
-
     def _update_cred(self):
         """
         Updates the reduced costs with the values from the
@@ -139,14 +135,13 @@ class LinearAssignment(object):
         ui = np.diag(self.c[:, self._x]) - self._v[self._x]
         self.cred = self.c - ui[:, None] - self._v[None, :]
 
-
     def _augment(self):
         """
         Finds a minimum cost path and adds it to the matching
         """
         #build a minimum cost tree
         self._build_tree()
-        
+
         #update prices
         delta = self._d[self._ready] - self._mu
         self._v[self._ready] += delta
@@ -164,12 +159,11 @@ class LinearAssignment(object):
                 break
         self._update_cred()
 
-
     def _build_tree(self):
         """
         Builds the tree finding an augmenting path. Alternates along
         matched and unmatched edges between X and Y. The paths are
-        stored in self._pred (new predecessor of nodes in Y), and 
+        stored in self._pred (new predecessor of nodes in Y), and
         self._x and self._y
         """
         #find unassigned i*
@@ -177,17 +171,17 @@ class LinearAssignment(object):
 
         #compute distances
         self._d = self.c[self._istar] - self._v
-        self._pred = np.zeros(self.n, dtype = np.int) + self._istar
-        
+        self._pred = np.zeros(self.n, dtype=np.int) + self._istar
+
         #initialize sets
-        #READY: set of nodes visited and in the path (whose price gets 
+        #READY: set of nodes visited and in the path (whose price gets
         #updated in augment)
         #SCAN: set of nodes at the bottom of the tree, which we need to
         #look at
         #T0DO: unvisited nodes
-        self._ready = np.zeros(self.n, dtype = np.bool)
-        self._scan = np.zeros(self.n, dtype = np.bool)
-        self._todo = np.zeros(self.n, dtype = np.bool) + True
+        self._ready = np.zeros(self.n, dtype=np.bool)
+        self._scan = np.zeros(self.n, dtype=np.bool)
+        self._todo = np.zeros(self.n, dtype=np.bool) + True
 
         while True:
             #populate scan with minimum reduced distances
@@ -218,7 +212,7 @@ class LinearAssignment(object):
             #update predecessors
             self._pred[shorter] = self._i
 
-            for self._j in np.argwhere((self._d == self._mu) \
+            for self._j in np.argwhere((self._d == self._mu)
                                        * self._todo).flatten():
                 if self._y[self._j] == -1:
                     return
