@@ -34,8 +34,9 @@ class SymmetrizedStructure(Structure):
         site_map = zip(self._sites, equivalent_positions)
         site_map = sorted(site_map, key=lambda x: x[1])
         self._equivalent_sites = [[x[0] for x in g]
-                                  for k, g in itertools.groupby(site_map,
-                                                        key=lambda x: x[1])]
+                                  for k, g
+                                  in itertools.groupby(site_map,
+                                                       key=lambda x: x[1])]
 
     @property
     def equivalent_sites(self):
